# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a
Changelog](https://keepachangelog.com/en/1.0.0/), and this project
adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.0] - 2023-03-29

### Added

- Initial release.
- Supports login and logout for Keycloak 16.1.1.

[0.1.0]: https://github.com/prokie/fastapi-oidc-auth/releases/tag/v0.1.0
